summaryrefslogtreecommitdiff
path: root/host/lib21/include/host_misc2.h
diff options
context:
space:
mode:
Diffstat (limited to 'host/lib21/include/host_misc2.h')
-rw-r--r--host/lib21/include/host_misc2.h22
1 files changed, 6 insertions, 16 deletions
diff --git a/host/lib21/include/host_misc2.h b/host/lib21/include/host_misc2.h
index 86ec13f0..5d891cad 100644
--- a/host/lib21/include/host_misc2.h
+++ b/host/lib21/include/host_misc2.h
@@ -9,28 +9,18 @@
#include <stdint.h>
#include <stdio.h>
-#include "2guid.h"
+#include "2id.h"
/* Length of string representation, including trailing '\0' */
-#define VB2_GUID_MIN_STRLEN (2 * NUM_GUID_BYTES + 1)
+#define VB2_ID_MIN_STRLEN (2 * VB2_ID_NUM_BYTES + 1)
/**
* Convert string to struct vb2_guid.
*
- * @param str Example: "C12A7328-F81F-11D2-BA4B-00A0C93EC93B"
- * @param guid Destination for binary representation
+ * @param str Example: "01ABef000042"
+ * @param id Destination for binary representation
* @return VB2_SUCCESS, or non-zero if error.
*/
-int vb2_str_to_guid(const char *str, struct vb2_guid *guid);
-
-/**
- * Convert struct vb2_guid to string.
- *
- * @param guid Binary representation
- * @param str Buffer for result "C12A7328-F81F-11D2-BA4B-00A0C93EC93B"
- * @return VB2_SUCCESS, or non-zero if error.
- */
-int vb2_guid_to_str(const struct vb2_guid *guid,
- char *buf, unsigned int buflen);
+int vb2_str_to_id(const char *str, struct vb2_id *id);
#endif /* VBOOT_REFERENCE_HOST_MISC2_H_ */
@@ -9,28 +9,18 @@
/**
- * Convert string to struct vb2_guid.
+ * Convert hex string to struct vb2_id.
*